bayespy.inference.vmp.nodes.gamma.GammaDistribution
===================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gamma

.. autoclass:: GammaDistribution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GammaDistribution.compute_cgf_from_parents
      ~GammaDistribution.compute_fixed_moments_and_f
      ~GammaDistribution.compute_gradient
      ~GammaDistribution.compute_logpdf
      ~GammaDistribution.compute_mask_to_parent
      ~GammaDistribution.compute_message_to_parent
      ~GammaDistribution.compute_moments_and_cgf
      ~GammaDistribution.compute_phi_from_parents
      ~GammaDistribution.plates_from_parent
      ~GammaDistribution.plates_to_parent
      ~GammaDistribution.random
   
   

   
   
   